@@ -629,6 +629,10 @@ dec_init(int use_assembler)
 	xvid_gbl_init_t   xvid_gbl_init;
 	xvid_dec_create_t xvid_dec_create;
 
+	/* Reset the structure with zeros */
+	memset(&xvid_gbl_init, 0, sizeof(xvid_gbl_init_t));
+	memset(&xvid_dec_create, 0, sizeof(xvid_dec_create_t));
+
 	/*------------------------------------------------------------------------
 	 * XviD core initialization
 	 *----------------------------------------------------------------------*/
@@ -680,6 +684,7 @@ dec_main(unsigned char *istream,
 	int ret;
 
 	xvid_dec_frame_t xvid_dec_frame;
+	memset(&xvid_dec_frame, 0, sizeof(xvid_dec_frame_t));
 
 	/* Set version */
 	xvid_dec_frame.version = XVID_VERSION;
