@@ -100,11 +100,22 @@ simplify_time(int *inc, int *base)
 		i--;
 	}
 
-	/* if neccessary, round to 65535 accuracy */
-	if (*base > 65535) {
-		float div = (float) *base / 65535;
-		*base = (int) (*base / div);
-		*inc = (int) (*inc / div);
+	if (*base > 65535 || *inc > 65535) {
+		int *biggest;
+		int *other;
+		float div;
+
+		if (*base > *inc) {
+			biggest = base;
+			other = inc;
+		} else {
+			biggest = inc;
+			other = base;
+		}
+		
+		div = ((float)*biggest)/((float)65535);
+		*biggest = (int)(((float)*biggest)/div);
+		*other = (int)(((float)*other)/div);
 	}
 }
 
